from .dict_and_html import (DOCTYPE, HTML_STYLE, TABLE_STYLE, dict_and_html)
from .d_ht_convert_rows import (convert_dict_rows_into_table_rows)
from .strategies.strategy_keys import attribute_strategy_for_key
from .strategies.strategy_values import attribute_strategy_for_value

__all__ = ["DOCTYPE",
           "HTML_STYLE",
           "TABLE_STYLE",
           "dict_and_html",
           "convert_dict_rows_into_table_rows",
           "attribute_strategy_for_key",
           "attribute_strategy_for_value"]
